@@ -1,10 +1,15 @@
+from django.conf import settings
 from django.test import TestCase
+from django.utils.unittest.case import skipIf
+
 from billing import get_gateway
 from billing.signals import transaction_was_successful, transaction_was_unsuccessful
 
+
 TEST_AMOUNT = 0.01
 
 
+@skipIf(not settings.MERCHANT_SETTINGS.get("bitcoin", None), "gateway not configured")
 class BitcoinGatewayTestCase(TestCase):
     def setUp(self):
         self.merchant = get_gateway("bitcoin")
